@@ -1,17 +1,11 @@
 import json
-import pytest
 
+import pytest
 from libnacl.secret import SecretBox
 
-from plenum.common.constants import TARGET_NYM, RAW, ENC, HASH
-from indy_common.constants import TXN_TYPE, ATTRIB, GET_ATTR, \
-    DATA, GET_NYM, reqOpKeys, GET_TXNS, GET_SCHEMA, GET_CLAIM_DEF, ACTION, \
-    NODE_UPGRADE, COMPLETE, FAIL, CONFIG_LEDGER_ID, POOL_UPGRADE, POOL_CONFIG, \
-    IN_PROGRESS, DISCLO, ATTR_NAMES, REVOCATION, SCHEMA, ENDPOINT, CLAIM_DEF, \
-    REF, SIGNATURE_TYPE, SCHEDULE, SHA256, \
-    TIMEOUT, JUSTIFICATION, JUSTIFICATION_MAX_SIZE, REINSTALL, WRITES
+from indy_common.constants import TXN_TYPE, ATTRIB, ENDPOINT
 from indy_common.types import ClientAttribOperation
-
+from plenum.common.constants import TARGET_NYM, RAW, ENC, HASH
 
 validator = ClientAttribOperation()
 
