@@ -30,3 +30,6 @@ class IndyTransactions(Transactions):
     GET_REVOC_REG_DEF = "115"
     GET_REVOC_REG = "116"
     GET_REVOC_REG_DELTA = "117"
+
+    POOL_RESTART = "118"
+    VALIDATOR_INFO = "119"
