@@ -1,12 +1,15 @@
 from copy import deepcopy
 
 from common.serializers.serialization import pool_state_serializer
+from indy_common.authorize.auth_actions import AuthActionEdit, AuthActionAdd
+from indy_common.authorize.auth_map import authMap, anyoneCanWriteMap
+from indy_common.authorize.auth_request_validator import WriteRequestValidator
+from indy_common.config_util import getConfig
 from plenum.common.constants import TARGET_NYM, DATA, ALIAS, SERVICES, \
-    BLS_KEY_PROOF
+    BLS_KEY_PROOF, VALIDATOR
 
 from plenum.common.ledger import Ledger
 from plenum.server.pool_req_handler import PoolRequestHandler as PHandler
-from indy_common.auth import Authoriser
 from indy_common.constants import NODE
 from indy_node.persistence.idr_cache import IdrCache
 from state.state import State
@@ -14,14 +17,37 @@ from state.state import State
 
 class PoolRequestHandler(PHandler):
     def __init__(self, ledger: Ledger, state: State,
-                 domainState: State, idrCache: IdrCache):
-        super().__init__(ledger, state, domainState)
+                 states, idrCache: IdrCache):
+        super().__init__(ledger, state, states)
         self.stateSerializer = pool_state_serializer
         self.idrCache = idrCache
+        self.write_req_validator = WriteRequestValidator(config=getConfig(),
+                                                         auth_map=authMap,
+                                                         cache=self.idrCache,
+                                                         anyone_can_write_map=anyoneCanWriteMap)
 
-    def isSteward(self, nym, isCommitted: bool=True):
+    def isSteward(self, nym, isCommitted: bool = True):
         return self.idrCache.hasSteward(nym, isCommitted)
 
+    def authErrorWhileAddingNode(self, request):
+        origin = request.identifier
+        operation = request.operation
+        data = operation.get(DATA, {})
+        error = self.dataErrorWhileValidating(data, skipKeys=False)
+        if error:
+            return error
+
+        if self.stewardHasNode(origin):
+            return "{} already has a node".format(origin)
+        error = self.isNodeDataConflicting(data)
+        if error:
+            return "existing data has conflicts with " \
+                   "request data {}. Error: {}".format(operation.get(DATA), error)
+        self.write_req_validator.validate(request,
+                                          [AuthActionAdd(txn_type=NODE,
+                                                         field=SERVICES,
+                                                         value=data.get(SERVICES, [VALIDATOR]))])
+
     def authErrorWhileUpdatingNode(self, request):
         origin = request.identifier
         isTrustee = self.idrCache.hasTrustee(origin, isCommitted=False)
@@ -41,12 +67,9 @@ class PoolRequestHandler(PHandler):
         isStewardOfNode = self.isStewardOfNode(
             origin, nodeNym, isCommitted=False)
 
-        actorRole = self.idrCache.getRole(origin, isCommitted=False)
         nodeInfo = self.getNodeData(nodeNym, isCommitted=False)
         data = deepcopy(data)
         data.pop(ALIAS, None)
-        vals = []
-        msgs = []
         for k in data:
             if k == BLS_KEY_PROOF:
                 continue
@@ -58,12 +81,9 @@ class PoolRequestHandler(PHandler):
                 if not newVal:
                     newVal = []
             if oldVal != newVal:
-                r, msg = Authoriser.authorised(NODE, actorRole,
-                                               field=k,
-                                               oldVal=oldVal,
-                                               newVal=newVal,
-                                               isActorOwnerOfSubject=isStewardOfNode)
-                vals.append(r)
-                msgs.append(msg)
-        msg = None if all(vals) else '\n'.join(msgs)
-        return msg
+                self.write_req_validator.validate(request,
+                                                  [AuthActionEdit(txn_type=NODE,
+                                                                  field=k,
+                                                                  old_value=oldVal,
+                                                                  new_value=newVal,
+                                                                  is_owner=isStewardOfNode)])
