@@ -1,15 +1,15 @@
 import pytest
 
-from plenum.test.bls.helper import change_bls_key, check_bls_key
-from plenum.test.conftest import pool_txn_stewards_data, stewards_and_wallets
+from indy_node.test.upgrade.helper import sdk_change_bls_key
+from plenum.test.bls.helper import check_bls_key
 
 
 @pytest.fixture(scope="module")
-def update_bls_keys(looper, tconf, nodeSet, stewards_and_wallets):
+def update_bls_keys(looper, tconf, nodeSet, sdk_pool_handle,
+                    sdk_wallet_stewards):
     node = nodeSet[0]
-    steward_client, steward_wallet = stewards_and_wallets[0]
-    new_blspk = change_bls_key(looper, nodeSet, node,
-                               steward_client, steward_wallet)
+    new_blspk = sdk_change_bls_key(looper, nodeSet, node,
+                                   sdk_pool_handle, sdk_wallet_stewards[0])
 
     check_bls_key(new_blspk, node, nodeSet)
 
